// GGame.cpp: implementation of the GGame class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "D3DXApp.h"
#include "GGame.h"
#include "MainFrm.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

const int controls[MAX_PLAYERS][3] = {
	{DIK_LEFT, DIK_RIGHT, DIK_RCONTROL},
	{DIK_A, DIK_S, DIK_LCONTROL},
	{DIK_N, DIK_M, DIK_SPACE},
	{DIK_NUMPADPLUS, DIK_NUMPADMINUS, DIK_NUMPADENTER},
};

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

GGame::GGame()
{
	m_font = new CD3DFont("Arial", 12, D3DFONT_BOLD);
	m_ground = 0;
	m_bGameAfgan = 0;
	m_autofire = false;
	m_houpani = true;
	m_smrti = true;

}

GGame::~GGame()
{

}

////////////////////////////////////////////////////////////////////////////////
void GGame::Init(CMainFrame *parent)
{
	GBase::Init(parent);

	m_bGameUSA   = d3dx.CreateTextureFromRes(AfxGetApp()->m_hInstance, "USA");
	m_bGameAfgan = d3dx.CreateTextureFromRes(AfxGetApp()->m_hInstance, "AFGAN");


	m_bShoot  = d3dx.CreateVirualTexture(m_bGameAfgan,  1, 245,   7,  6);

	m_bUsa    = d3dx.CreateVirualTexture(m_bGameUSA,  1,   1,  70, 172);
	m_bPlaneL = d3dx.CreateVirualTexture(m_bGameUSA,  1, 174, 168, 168);
	m_bPlaneR = d3dx.CreateVirualTexture(m_bGameUSA,  1, 343, 168, 168);
	
	m_bUsaDead[0] = d3dx.CreateVirualTexture(m_bGameUSA,  924,  2, 70, 30);
	m_bUsaDead[1] = d3dx.CreateVirualTexture(m_bGameUSA,  924, 34, 70, 30);
	m_bUsaDead[2] = d3dx.CreateVirualTexture(m_bGameUSA,  924, 66, 70, 30);
	m_bUsaDead[3] = d3dx.CreateVirualTexture(m_bGameUSA,  924, 98, 70, 30);

	m_font->InitDeviceObjects(d3dx.m_dev);
}

////////////////////////////////////////////////////////////////////////////////
void GGame::Move()
{
	if (m_lives < 0 || m_pause) return;

	int i;
	dinput.Update();

	for (i = 0; i < m_players; i ++)
		m_afgan[i].Move(dinput.m_key[controls[i][0]], dinput.m_key[controls[i][1]], dinput.m_key[controls[i][2]] || m_autofire);

	for (i = 0; i < MAX_COMPUTERS; i++) {
		if (m_usa[i].Move(m_smrti)) m_lives--;
		for (int j = 0; j < m_players; j++)
			if (m_usa[i].TestHit(&m_afgan[j].m_gshoot[0])) 
				if (m_afgan[j].KilledNew()) m_lives++;
	}

	for (i = 0; i < m_planes; i++) {
		m_plane[i].Move(this);
		// test na zasah
		for (int j = 0; j < m_players; j++)
			if (m_plane[i].TestHit(&m_afgan[j].m_gshoot[0])) 
				for (int k = 0; k < 5; k++) 
					if (m_afgan[j].KilledNew()) m_lives++;
	}

}

////////////////////////////////////////////////////////////////////////////////
void GGame::Draw()
{
	int i;
	m_font->RestoreDeviceObjects();
	d3dx.BeginScene();

	d3dx.Draw(m_bGround, 400, 300, 0, 1.5625, 1.25, 255);

	for (i = 0; i < m_planes; i++)
		m_plane[i].Draw();

	for (i = 0; i < MAX_COMPUTERS; i++)
		m_usa[i].Draw(m_houpani);

	for (i = 0; i < m_players; i++)
		m_afgan[i].Draw();

	if (m_lives >= 0) {
		char s[50];
		sprintf(s, "Zivotu : %d", m_lives);
		m_font->DrawText(400, 25, D3DCOLOR_ARGB(255, 255, 255, 255), s, D3DFONT_CENTERED);
	}
	else
		m_font->DrawText(400, 300, D3DCOLOR_ARGB(255, 255, 0, 0), "BYL JSI ZABIT", D3DFONT_CENTERED);


	if (m_pause) 
		m_font->DrawText(400, 300, D3DCOLOR_ARGB(255, 255, 0, 0), "PAUZA", D3DFONT_CENTERED);

	d3dx.EndScene();
	m_font->InvalidateDeviceObjects();
}

////////////////////////////////////////////////////////////////////////////////
int GGame::OnKey(int nChar)
{
	switch (nChar) {
	case 27 : // ECS
		if (m_players == 1) 
			m_pParent->EndGame(m_afgan[0].m_killed);
		else
			m_pParent->m_base = &m_pParent->m_menu;
		DestroyGFX();
		break;
	case 80:
		m_pause = !m_pause;
		break;
	case 112 : // F1 - autofire
		m_autofire = !m_autofire;
		break;
	case 113 : // F2 - houpani
		m_houpani = !m_houpani;
		break;
	case 114 : // F3 - smrti
		m_smrti = !m_smrti;
		break;
	}

	return MENU_DEFAULT;
}

////////////////////////////////////////////////////////////////////////////////
void GGame::StartGame(int players, int ground)
{

	m_ground = ground;
	m_players = players;
	m_planes  = players*3;

	InitGFX();

	int i;

	for (i = 0; i < m_players; i++)
		m_afgan[i].Init((SCREEN_X/(m_players+1)) * (i+1), SCREEN_Y-60, m_bAfgan, m_bShoot, m_font);

	for (i = 0; i < m_planes; i++) 
		m_plane[i].Init(m_bPlaneL, m_bPlaneR, 30 + i*50/m_planes, 4+players);

	for (i = 0; i < MAX_COMPUTERS; i++)
		m_usa[i].Init(m_bUsa, m_bUsaDead);

	m_lives = 3;
	m_pause = false;
}


////////////////////////////////////////////////////////////////////////////////
void GGame::AddUSA(double x, double y)
{
	for (int i = 0; i < MAX_COMPUTERS; i++)
		if (m_usa[i].m_active == false) {
			m_usa[i].Activate(x, y);
			break;
		}
}

void GGame::InitGFX()
{
	CString s;
	s.Format("GROUND%d",m_ground);
	m_bGround = d3dx.CreateTextureFromRes(AfxGetApp()->m_hInstance, s);

	m_bAfgan  = d3dx.CreateVirualTexture(m_bGameAfgan,  1, 1+m_ground*81,  50, 80);
}

void GGame::DestroyGFX()
{
	d3dx.DestroyTexture(m_bGround);
	d3dx.DestroyTexture(m_bAfgan);
}
