// GPlane.cpp: implementation of the GPlane class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "D3DXApp.h"
#include "GPlane.h"
#include "GGame.h"
#include "GShoot.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

GPlane::GPlane()
{
	m_bPlaneL = 0;
	m_bPlaneR = 0;
	m_lives = 1;
}

GPlane::~GPlane()
{

}

void GPlane::Init(int bPlaneL,int bPlaneR, double y, int maxlives)
{
	m_x = -1000;
	m_torestore = 50 + rand()%100;
	m_y = y;
	m_yO = y;

	m_tojump = 1;

	m_lives = m_Mlives = maxlives;

	m_bPlaneL = bPlaneL;
	m_bPlaneR = bPlaneR;
}

void GPlane::Draw()
{
	if (m_speed < 0) d3dx.Draw(m_bPlaneL, m_x, m_y, m_uhelpadu, 1, 1, 255, m_anim/4);
	else d3dx.Draw(m_bPlaneR, m_x, m_y, m_uhelpadu, 1, 1, 255, m_anim/4);
}

void GPlane::Move(GGame *base)
{

	if (m_x < -200 || m_x > SCREEN_X+100) 
		if (--m_torestore == 0) Restore();
		else return;

	if (m_x > 20 && m_x < SCREEN_X-20 && m_lives > 0) {
		m_jump++;
		if (m_jumps[m_jump] == true)
			base->AddUSA(m_x, m_y);
	}

	m_x += m_speed;

	if (m_anim) {
		if (++m_anim >= 48) m_anim = 1;
		if (abs(m_uhelpadu) < 0.4) m_uhelpadu -= 0.005 * (m_speed/abs(m_speed));
	}

	if (m_lives == 0) m_y += 3+rand()%2;

}

void GPlane::Restore()
{

	int i;

	if (rand()%2 == 0) {
		m_x = -100;
		m_speed = 8 + rand()%9;
	}
	else {
		m_x = 740;
		m_speed = -(8 + rand()%9);
	}

	m_torestore = 50 + rand()%100;

	int jumps = (int)(m_tojump + ((double)(rand()%21))/10 - 1);
	int wjump = 600/abs(m_speed);
	for (i = 0; i < MAX_JUMPS; i++) m_jumps[i] = false;


	if (wjump > MAX_JUMPS) wjump = MAX_JUMPS;
	for (i = 0; i < jumps; i++)
		m_jumps[rand()%wjump] = true;

	m_jump = -1;

	m_tojump  += 0.5;

	if (m_lives == 0) m_lives = m_Mlives;	

	m_y = m_yO;

	m_uhelpadu = 0;

	m_anim = 0;
}

inline double abs(double x) 
{
	if (x < 0) return -x;
	return x;
}


bool GPlane::TestHit(GShoot *shoot)
{
	if (m_lives == 0) return false;

	CRect rect;
	rect.SetRect(m_x-80,m_y-30,m_x+80,m_y+30);

	for (int i = 0; i < MAX_SHOOTS; i++, shoot++) {
		if (shoot->m_valid == false) continue;
		if (rect.PtInRect(CPoint(shoot->m_x, shoot->m_y))) {
			m_lives--;
			shoot->HitPlane();
			if (m_lives == 0) {
				m_anim = 1; // zahajeni animace padajiciho letounu
				return true;
			}
		}
	}
	return false;
}
