/*  Hippo Games - 2000 (C) - http://www.prog.cz/hippo/
 *    __________________________________________________
 *   /\     __  __    _____   ______   ______   ______  \
 *   \ \   /\ \|\ \  /\_  _\ /\  __ \ /\  __ \ /\  __ \  \
 *    \ \  \ \ \_\ \ \//\ \/ \ \ \_\ \\ \ \_\ \\ \ \ \ \  \
 *     \ \  \ \  __ \  \ \ \  \ \  __/ \ \  __/ \ \ \ \ \  \
 *      \ \  \ \ \/\ \  \_\ \_ \ \ \/   \ \ \/   \ \ \_\ \  \
 *       \ \  \ \_\ \_\ /\____\ \ \_\    \ \_\    \ \_____\  \
 *        \ \  \/_/\/_/ \/____/  \/_/     \/_/     \/_____/   \
 *         \ \_________________________________________________\
 *          \/_________________________________________________/
 *                           
 *  
 *  Sub     : Funkce pro DirectInput
 *
 *  File    : HDInput.cpp
 *  
 *  Projekt : HDXII
 *  
 *  Autor   : Bernard Lidicky [berny@prog.cz]
 *
 *  Datum   : 29.12.2000
 *
 */      

#include "stdafx.h"
#include "HDInput.h"


HDInput dinput;


//////////////////////////////////////////////////////////////////////////////////
// NULL-ovaci konstruktor
//////////////////////////////////////////////////////////////////////////////////
HDInput::HDInput()
{
	m_lpKey = NULL;
	m_lpMouse = NULL;
	m_lpDI = NULL;
}

//////////////////////////////////////////////////////////////////////////////////
// Destruktor - releasuje to, co je potreba
//////////////////////////////////////////////////////////////////////////////////
HDInput::~HDInput()
{
	if (m_lpKey != NULL) {
		m_lpKey->Unacquire();
		m_lpKey->Release();
		m_lpKey = NULL;
	}

	if (m_lpMouse != NULL) {
		m_lpMouse->Unacquire();
		m_lpMouse->Release();
		m_lpMouse = NULL;
	}

	if (m_lpDI != NULL) {
		m_lpDI->Release();
		m_lpDI = NULL;
	}
}

//////////////////////////////////////////////////////////////////////////////////
// Hlavni tvorici fce. Oba parametry mohou byt NULL - automaticke vyplneni
// parametru. Vytvori obsluhu pro klavesnici i mys
//////////////////////////////////////////////////////////////////////////////////
bool HDInput::Create(HINSTANCE hinst, HWND hwnd)
{

	if (hwnd == NULL)
		hwnd = AfxGetMainWnd()->GetSafeHwnd();

	if (hinst == NULL)
		hinst = AfxGetApp()->m_hInstance;


	// tvoreni DirectInput
	if (DirectInput8Create(hinst,DIRECTINPUT_VERSION , IID_IDirectInput8A, (void**)&m_lpDI, NULL) != DI_OK) return false;

	// Klavesnice
	if (m_lpDI->CreateDevice(GUID_SysKeyboard, (IDirectInputDevice8A**)&m_lpKey, NULL) != DI_OK) return false;
	m_lpKey->SetDataFormat(&c_dfDIKeyboard);
	m_lpKey->SetCooperativeLevel(hwnd, DISCL_NONEXCLUSIVE | DISCL_FOREGROUND);
	if (m_lpKey->Acquire() != DI_OK) return false;

	// Mys
	if (m_lpDI->CreateDevice(GUID_SysMouse, (IDirectInputDevice8A**)&m_lpMouse, NULL) != DI_OK) return false;
	m_lpMouse->SetDataFormat(&c_dfDIMouse);
	m_lpMouse->SetCooperativeLevel(hwnd, DISCL_NONEXCLUSIVE | DISCL_FOREGROUND);
	if (m_lpMouse->Acquire()  != DI_OK) return false;

	return true;
}

//////////////////////////////////////////////////////////////////////////////////
// Aktualizace vstupnich dat. Melo by se volat vzdy pred pouzitim dat.
//////////////////////////////////////////////////////////////////////////////////
void HDInput::Update()
{
	if(m_lpKey->GetDeviceState(256, &m_key) == (DIERR_INPUTLOST | DIERR_NOTACQUIRED))
		m_lpKey->Acquire();


	DIMOUSESTATE mousestats;

	if(m_lpMouse->GetDeviceState(sizeof(mousestats), &mousestats) == (DIERR_INPUTLOST | DIERR_NOTACQUIRED))
		m_lpMouse->Acquire();
	else {
		m_x = mousestats.lX;
		m_y = mousestats.lY;
		m_z = mousestats.lZ;

		for(int i = 0; i < 4; i++)
			m_b[i] = mousestats.rgbButtons[i];
	}
}


//////////////////////////////////////////////////////////////////////////////////
// operator, ktery umoznuje pouzivat promenou i jako LPDIRECTINPUT
//////////////////////////////////////////////////////////////////////////////////
HDInput::operator LPDIRECTINPUT8() {
	return m_lpDI;
}
